# Installation

To use the Prescient SDK, you first need to install it and its dependencies

1. Install or update Python

    The Prescient SDK supports Python 3.9 or later.

    For information about how to get the latest version of Python, see the official [Python documentation](https://www.python.org/downloads/).

1. Install Prescient SDK

```
pip install prescient-sdk
```